"""imgSeekLib contents

imgSeek modules

    begin                : Sat Dec 14 2002
    copyright            : (C) 2002 by Ricardo Niederberger Cabral
    email                : nieder|at|mail.ru
    Time-stamp:            <2005-04-17 18:43:21 rnc>

"""

__version__ = "0.8.5"

__all__ = ["Error",
           "dbCallbacks",
           "Settings",
           "EXIF",
           "IptcExtract",
           "SlideShowDialog",
           "BatchEditWnd",
           "ImageDB",
           "BatchEditForm",
           "customWidgets",
           "DuplicateWiz",
           "RenameWiz",
           "ExportForm",
           "CSVImportForm",
           "ExportWnd",
           "CSVImportWnd",
           "DuplicateForm",
           "RenameForm",
           "GroupPickerForm",
           "GroupPickerWnd",
           "HTMLAlbum",
           "imgdb",
           "MainForm",
           "AlbumWiz",
           "AlbumForm",
           "helpText",
           "MetaWnd",
           "MetaForm",
           "Transforms",
           "imgSeekApp",
           ]
